/****************************************************************************
** Meta object code from reading C++ file 'wallpaper_integration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreenlocker-6.6.90/settings/wallpaper_integration.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wallpaper_integration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLocker::WallpaperIntegration::qt_create_metaobjectdata<qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLocker::WallpaperIntegration",
        "packageChanged",
        "",
        "configurationChanged",
        "isLoadingChanged",
        "accentColorChanged",
        "openUrlRequested",
        "QUrl",
        "url",
        "contextualActionsChanged",
        "QList<QAction*>",
        "actions",
        "pluginName",
        "configuration",
        "KConfigPropertyMap*",
        "contextualActions",
        "QQmlListProperty<QAction>",
        "loading",
        "accentColor",
        "QColor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'packageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLoadingChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accentColorChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openUrlRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'contextualActionsChanged'
        QtMocHelpers::SignalData<void(const QList<QAction*> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pluginName'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'configuration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'contextualActions'
        QtMocHelpers::PropertyData<QQmlListProperty<QAction>>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'loading'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'accentColor'
        QtMocHelpers::PropertyData<QColor>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperIntegration, qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenLocker::WallpaperIntegration::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>.metaTypes,
    nullptr
} };

void ScreenLocker::WallpaperIntegration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperIntegration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->packageChanged(); break;
        case 1: _t->configurationChanged(); break;
        case 2: _t->isLoadingChanged(); break;
        case 3: _t->accentColorChanged(); break;
        case 4: _t->openUrlRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->contextualActionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)()>(_a, &WallpaperIntegration::packageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)()>(_a, &WallpaperIntegration::configurationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)()>(_a, &WallpaperIntegration::isLoadingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)()>(_a, &WallpaperIntegration::accentColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)(const QUrl & )>(_a, &WallpaperIntegration::openUrlRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperIntegration::*)(const QList<QAction*> & )>(_a, &WallpaperIntegration::contextualActionsChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KConfigPropertyMap* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->pluginName(); break;
        case 1: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->configuration(); break;
        case 2: *reinterpret_cast<QQmlListProperty<QAction>*>(_v) = _t->qmlContextualActions(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_loading; break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->accentColor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3:
            if (QtMocHelpers::setProperty(_t->m_loading, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->isLoadingChanged();
            break;
        case 4: _t->setAccentColor(*reinterpret_cast<QColor*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ScreenLocker::WallpaperIntegration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLocker::WallpaperIntegration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker20WallpaperIntegrationE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int ScreenLocker::WallpaperIntegration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ScreenLocker::WallpaperIntegration::packageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ScreenLocker::WallpaperIntegration::configurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ScreenLocker::WallpaperIntegration::isLoadingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ScreenLocker::WallpaperIntegration::accentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ScreenLocker::WallpaperIntegration::openUrlRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ScreenLocker::WallpaperIntegration::contextualActionsChanged(const QList<QAction*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
