/****************************************************************************
** Meta object code from reading C++ file 'pamauthenticators.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreenlocker-6.6.90/greeter/pamauthenticators.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pamauthenticators.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PamAuthenticatorsE_t {};
} // unnamed namespace

template <> constexpr inline auto PamAuthenticators::qt_create_metaobjectdata<qt_meta_tag_ZN17PamAuthenticatorsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PamAuthenticators",
        "stateChanged",
        "",
        "busyChanged",
        "promptChanged",
        "promptForSecretChanged",
        "infoMessageChanged",
        "errorMessageChanged",
        "succeeded",
        "authenticatorTypesChanged",
        "failed",
        "PamAuthenticator::NoninteractiveAuthenticatorTypes",
        "what",
        "PamAuthenticator*",
        "authenticator",
        "noninteractiveError",
        "noninteractiveInfo",
        "loginFailedDelayStarted",
        "uSecDelay",
        "hadPromptChanged",
        "startAuthenticating",
        "stopAuthenticating",
        "respond",
        "response",
        "cancel",
        "busy",
        "prompt",
        "promptForSecret",
        "infoMessage",
        "errorMessage",
        "unlocked",
        "authenticatorTypes",
        "state",
        "AuthenticatorsState",
        "hadPrompt",
        "Idle",
        "Authenticating"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'promptChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'promptForSecretChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'infoMessageChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'succeeded'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authenticatorTypesChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(PamAuthenticator::NoninteractiveAuthenticatorTypes, PamAuthenticator *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'noninteractiveError'
        QtMocHelpers::SignalData<void(PamAuthenticator::NoninteractiveAuthenticatorTypes, PamAuthenticator *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'noninteractiveInfo'
        QtMocHelpers::SignalData<void(PamAuthenticator::NoninteractiveAuthenticatorTypes, PamAuthenticator *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'loginFailedDelayStarted'
        QtMocHelpers::SignalData<void(PamAuthenticator::NoninteractiveAuthenticatorTypes, PamAuthenticator *, const uint)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 }, { QMetaType::UInt, 18 },
        }}),
        // Signal 'hadPromptChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'startAuthenticating'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stopAuthenticating'
        QtMocHelpers::MethodData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'respond'
        QtMocHelpers::MethodData<void(const QByteArray &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 23 },
        }}),
        // Method 'cancel'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'prompt'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'promptForSecret'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'infoMessage'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags, 4),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'unlocked'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'authenticatorTypes'
        QtMocHelpers::PropertyData<PamAuthenticator::NoninteractiveAuthenticatorTypes>(31, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'state'
        QtMocHelpers::PropertyData<enum AuthenticatorsState>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'hadPrompt'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AuthenticatorsState'
        QtMocHelpers::EnumData<enum AuthenticatorsState>(33, 33, QMC::EnumFlags{}).add({
            {   35, AuthenticatorsState::Idle },
            {   36, AuthenticatorsState::Authenticating },
        }),
    };
    return QtMocHelpers::metaObjectData<PamAuthenticators, qt_meta_tag_ZN17PamAuthenticatorsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17PamAuthenticatorsE[] = {
    QMetaObject::SuperData::link<PamAuthenticator::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject PamAuthenticators::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PamAuthenticatorsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PamAuthenticatorsE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17PamAuthenticatorsE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PamAuthenticatorsE_t>.metaTypes,
    nullptr
} };

void PamAuthenticators::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PamAuthenticators *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->busyChanged(); break;
        case 2: _t->promptChanged(); break;
        case 3: _t->promptForSecretChanged(); break;
        case 4: _t->infoMessageChanged(); break;
        case 5: _t->errorMessageChanged(); break;
        case 6: _t->succeeded(); break;
        case 7: _t->authenticatorTypesChanged(); break;
        case 8: _t->failed((*reinterpret_cast<std::add_pointer_t<PamAuthenticator::NoninteractiveAuthenticatorTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PamAuthenticator*>>(_a[2]))); break;
        case 9: _t->noninteractiveError((*reinterpret_cast<std::add_pointer_t<PamAuthenticator::NoninteractiveAuthenticatorTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PamAuthenticator*>>(_a[2]))); break;
        case 10: _t->noninteractiveInfo((*reinterpret_cast<std::add_pointer_t<PamAuthenticator::NoninteractiveAuthenticatorTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PamAuthenticator*>>(_a[2]))); break;
        case 11: _t->loginFailedDelayStarted((*reinterpret_cast<std::add_pointer_t<PamAuthenticator::NoninteractiveAuthenticatorTypes>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PamAuthenticator*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 12: _t->hadPromptChanged(); break;
        case 13: _t->startAuthenticating(); break;
        case 14: _t->stopAuthenticating(); break;
        case 15: _t->respond((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 16: _t->cancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PamAuthenticator* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PamAuthenticator* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PamAuthenticator* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PamAuthenticator* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::busyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::promptChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::promptForSecretChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::infoMessageChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::errorMessageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::succeeded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::authenticatorTypesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)(PamAuthenticator::NoninteractiveAuthenticatorTypes , PamAuthenticator * )>(_a, &PamAuthenticators::failed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)(PamAuthenticator::NoninteractiveAuthenticatorTypes , PamAuthenticator * )>(_a, &PamAuthenticators::noninteractiveError, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)(PamAuthenticator::NoninteractiveAuthenticatorTypes , PamAuthenticator * )>(_a, &PamAuthenticators::noninteractiveInfo, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)(PamAuthenticator::NoninteractiveAuthenticatorTypes , PamAuthenticator * , const uint )>(_a, &PamAuthenticators::loginFailedDelayStarted, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PamAuthenticators::*)()>(_a, &PamAuthenticators::hadPromptChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->prompt(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->promptForSecret(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->infoMessage(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isUnlocked(); break;
        case 6: *reinterpret_cast<PamAuthenticator::NoninteractiveAuthenticatorTypes*>(_v) = _t->authenticatorTypes(); break;
        case 7: *reinterpret_cast<enum AuthenticatorsState*>(_v) = _t->state(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hadPrompt(); break;
        default: break;
        }
    }
}

const QMetaObject *PamAuthenticators::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PamAuthenticators::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PamAuthenticatorsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PamAuthenticators::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PamAuthenticators::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PamAuthenticators::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PamAuthenticators::promptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PamAuthenticators::promptForSecretChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PamAuthenticators::infoMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PamAuthenticators::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PamAuthenticators::succeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PamAuthenticators::authenticatorTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PamAuthenticators::failed(PamAuthenticator::NoninteractiveAuthenticatorTypes _t1, PamAuthenticator * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void PamAuthenticators::noninteractiveError(PamAuthenticator::NoninteractiveAuthenticatorTypes _t1, PamAuthenticator * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void PamAuthenticators::noninteractiveInfo(PamAuthenticator::NoninteractiveAuthenticatorTypes _t1, PamAuthenticator * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void PamAuthenticators::loginFailedDelayStarted(PamAuthenticator::NoninteractiveAuthenticatorTypes _t1, PamAuthenticator * _t2, const uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void PamAuthenticators::hadPromptChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
