/****************************************************************************
** Meta object code from reading C++ file 'interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../kscreenlocker-6.6.90/interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLocker::PowerInhibitor::qt_create_metaobjectdata<qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLocker::PowerInhibitor"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerInhibitor, qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenLocker::PowerInhibitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>.metaTypes,
    nullptr
} };

void ScreenLocker::PowerInhibitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerInhibitor *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenLocker::PowerInhibitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLocker::PowerInhibitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker14PowerInhibitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenLocker::PowerInhibitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN12ScreenLocker9InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenLocker::Interface::qt_create_metaobjectdata<qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenLocker::Interface",
        "D-Bus Interface",
        "org.freedesktop.ScreenSaver",
        "ActiveChanged",
        "",
        "state",
        "AboutToLock",
        "Lock",
        "SimulateUserActivity",
        "SetActive",
        "GetActive",
        "GetActiveTime",
        "GetSessionIdleTime",
        "Inhibit",
        "application_name",
        "reason_for_inhibit",
        "UnInhibit",
        "cookie",
        "Throttle",
        "UnThrottle",
        "configure",
        "slotLocked",
        "slotUnlocked",
        "serviceUnregistered",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'AboutToLock'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Lock'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SimulateUserActivity'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetActive'
        QtMocHelpers::SlotData<bool(bool)>(9, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'GetActive'
        QtMocHelpers::SlotData<bool()>(10, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetActiveTime'
        QtMocHelpers::SlotData<uint()>(11, 4, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'GetSessionIdleTime'
        QtMocHelpers::SlotData<uint()>(12, 4, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<uint(const QString &, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'UnInhibit'
        QtMocHelpers::SlotData<void(uint)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Slot 'Throttle'
        QtMocHelpers::SlotData<uint(const QString &, const QString &)>(18, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'UnThrottle'
        QtMocHelpers::SlotData<void(uint)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Slot 'configure'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLocked'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUnlocked'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'serviceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Interface, qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenLocker::Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>.metaTypes,
    nullptr
} };

void ScreenLocker::Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->AboutToLock(); break;
        case 2: _t->Lock(); break;
        case 3: _t->SimulateUserActivity(); break;
        case 4: { bool _r = _t->SetActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->GetActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { uint _r = _t->GetActiveTime();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 7: { uint _r = _t->GetSessionIdleTime();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 8: { uint _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->UnInhibit((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: { uint _r = _t->Throttle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->UnThrottle((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: _t->configure(); break;
        case 13: _t->slotLocked(); break;
        case 14: _t->slotUnlocked(); break;
        case 15: _t->serviceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Interface::*)(bool )>(_a, &Interface::ActiveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Interface::*)()>(_a, &Interface::AboutToLock, 1))
            return;
    }
}

const QMetaObject *ScreenLocker::Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenLocker::Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ScreenLocker9InterfaceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenLocker::Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ScreenLocker::Interface::ActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ScreenLocker::Interface::AboutToLock()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
