/****************************************************************************
** Meta object code from reading C++ file 'kscreensaversettingsbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kscreensaversettingsbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kscreensaversettingsbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto KScreenSaverSettingsBase::qt_create_metaobjectdata<qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KScreenSaverSettingsBase",
        "AutolockChanged",
        "",
        "TimeoutChanged",
        "LockChanged",
        "LockGraceChanged",
        "RequirePasswordChanged",
        "LockOnResumeChanged",
        "LockOnStartChanged",
        "ThemeChanged",
        "wallpaperPluginIdChanged",
        "autolock",
        "isAutolockImmutable",
        "timeout",
        "isTimeoutImmutable",
        "lock",
        "isLockImmutable",
        "lockGrace",
        "isLockGraceImmutable",
        "requirePassword",
        "isRequirePasswordImmutable",
        "lockOnResume",
        "isLockOnResumeImmutable",
        "lockOnStart",
        "isLockOnStartImmutable",
        "theme",
        "isThemeImmutable",
        "wallpaperPluginId",
        "isWallpaperPluginIdImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AutolockChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TimeoutChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LockChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LockGraceChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RequirePasswordChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LockOnResumeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LockOnStartChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ThemeChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wallpaperPluginIdChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'autolock'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isAutolockImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timeout'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lock'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isLockImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lockGrace'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isLockGraceImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'requirePassword'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isRequirePasswordImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lockOnResume'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isLockOnResumeImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lockOnStart'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isLockOnStartImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'theme'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isThemeImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wallpaperPluginId'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isWallpaperPluginIdImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KScreenSaverSettingsBase, qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KScreenSaverSettingsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>.metaTypes,
    nullptr
} };

void KScreenSaverSettingsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KScreenSaverSettingsBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AutolockChanged(); break;
        case 1: _t->TimeoutChanged(); break;
        case 2: _t->LockChanged(); break;
        case 3: _t->LockGraceChanged(); break;
        case 4: _t->RequirePasswordChanged(); break;
        case 5: _t->LockOnResumeChanged(); break;
        case 6: _t->LockOnStartChanged(); break;
        case 7: _t->ThemeChanged(); break;
        case 8: _t->wallpaperPluginIdChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::AutolockChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::TimeoutChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::LockChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::LockGraceChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::RequirePasswordChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::LockOnResumeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::LockOnStartChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::ThemeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KScreenSaverSettingsBase::*)()>(_a, &KScreenSaverSettingsBase::wallpaperPluginIdChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->autolock(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isAutolockImmutable(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->timeout(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isTimeoutImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->lock(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isLockImmutable(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lockGrace(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLockGraceImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->requirePassword(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isRequirePasswordImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->lockOnResume(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isLockOnResumeImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->lockOnStart(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isLockOnStartImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->theme(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isThemeImmutable(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->wallpaperPluginId(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isWallpaperPluginIdImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAutolock(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setTimeout(*reinterpret_cast<double*>(_v)); break;
        case 4: _t->setLock(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLockGrace(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setRequirePassword(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setLockOnResume(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setLockOnStart(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setTheme(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setWallpaperPluginId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KScreenSaverSettingsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreenSaverSettingsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KScreenSaverSettingsBaseE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KScreenSaverSettingsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KScreenSaverSettingsBase::AutolockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KScreenSaverSettingsBase::TimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KScreenSaverSettingsBase::LockChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KScreenSaverSettingsBase::LockGraceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KScreenSaverSettingsBase::RequirePasswordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KScreenSaverSettingsBase::LockOnResumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KScreenSaverSettingsBase::LockOnStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KScreenSaverSettingsBase::ThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KScreenSaverSettingsBase::wallpaperPluginIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
