/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.screensaver.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KSCREENSAVERADAPTOR_H
#define KSCREENSAVERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "interface.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.screensaver
 */
class KScreenSaverAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.screensaver")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.screensaver\">\n"
"    <method name=\"configure\"/>\n"
"    <signal name=\"AboutToLock\"/>\n"
"  </interface>\n"
        "")
public:
    KScreenSaverAdaptor(ScreenLocker::Interface *parent);
    ~KScreenSaverAdaptor() override;

    inline ScreenLocker::Interface *parent() const
    { return static_cast<ScreenLocker::Interface *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void configure();
Q_SIGNALS: // SIGNALS
    void AboutToLock();
};

#endif
